@@ -112,7 +112,7 @@ class visualize_activations(object):
         
     def _load_model_loss(self):
             
-        self.viewer.add_image(self.image.astype('float32'), name= 'Image', blending= 'additive' )    
+            
             
         if self.oneat_vollnet: 
             
@@ -256,7 +256,9 @@ class visualize_activations(object):
                 
     def _draw_boxes(self):    
         
-        viz_box = VisualizeBoxes(viewer = self.viewer, key_categories = self.key_categories, event_threshold = self.event_threshold)
+        if isinstance(self.model, any(NEATVollNet, NEATTResNet, NEATLRNet, NEATResNet, NEATTResNet)):
+          
+           viz_box = VisualizeBoxes(viewer = self.viewer, key_categories = self.key_categories, event_threshold = self.event_threshold)
         
         if self.oneat_vollnet:
              
@@ -317,12 +319,12 @@ class visualize_activations(object):
         self._activations_predictions()
         
         
-        
+        self.viewer.add_image(self.image.astype('float32'), name= 'Image', blending= 'additive' )
         for (k,v) in self.all_max_activations.items():
             time = k
             activations = v
             for count, activation in enumerate(activations):
-                max_activation = np.sum(activation, axis = -1)
+                max_activation = np.sum(activation, axis = -1)[0,:]
                 print(f'activation_function_shape: {max_activation.shape}')          
                 self.viewer.add_image(max_activation.astype('float32'), name= 'Activation_count' + str(count) + 'time_' + str(time), blending= 'additive', colormap='inferno' )
         napari.run()
@@ -333,13 +335,15 @@ class visualize_activations(object):
         print('boxes done, creating activation maps')
         self._activations_predictions()
         
-        
-        
+        if self.visualize_point is not None:
+          self.viewer.add_image(self.image[self.visualize_point,:].astype('float32'), name= 'Image', blending= 'additive' )
+        else:
+          self.viewer.add_image(self.image.astype('float32'), name= 'Image', blending= 'additive' )   
         for (k,v) in self.all_max_activations.items():
             time = k
             activations = v
             for count, activation in enumerate(activations):
-                max_activation = np.sum(activation, axis = -1)
+                max_activation = np.sum(activation, axis = -1)[0,:]
                 print(f'activation_function_shape: {max_activation.shape}')          
                 self.viewer.add_image(max_activation.astype('float32'), name= 'Activation_count' + str(count) + 'time_' + str(time), blending= 'additive', colormap='inferno' )
         napari.run()    
@@ -351,4 +355,5 @@ class visualize_activations(object):
         self._model_prediction()
         print('prediction done, creating boxes')
         self._draw_boxes()
+        self.viewer.add_image(self.image.astype('float32'), name= 'Image', blending= 'additive' )
         napari.run()    
\ No newline at end of file
